import { geoPeirceQuincuncial, geoBertin1953, geoNaturalEarth1, geoPath, geoGraticule, format } from 'd3';

export const Marks = ({
  geoLines: { lines },
  worldAtlas: { countries, land, interiors },
  cities,
  sizeScale,
  sizeValue,
  coSizeValue,
  coSizeScale,
  spin,
}) => {
  //const projection = geoPeirceQuincuncial().rotate([-90,-90,225]);
  const projection = geoNaturalEarth1().rotate(spin);
  const path = geoPath(projection);
  const graticule = geoGraticule();

  return (
    <g className="marks">
      <path className="" d={path({ type: 'Sphere' })} />
      {land.features.map((feature) => (
        <path className="land" d={path(feature)} />
      ))}
      <path className="graticules" d={path(graticule())} />
      {lines.features.map((feature) => (
        <path className="geo" d={path(feature)} />
      ))}
      {countries.features.map((feature) => {
        
        //console.log(feature.properties.pop)
        
        return (
        <path
          className={(feature.properties.pop == 0) ?
              "countries no-data" : "countries"
          }
          d={path(feature)}
          opacity={coSizeScale(feature.properties.pop)}
        >
          <title>{feature.properties.name} -
          {(feature.properties.pop == 0) ?
              '[no data]' : format('.2s')(feature.properties.pop).replace('G', 'B')
          }</title>
        </path>
      )})}
      <path className="interiors" d={path(interiors)} />
      {cities.map((d) => {
        const [x, y] = projection([d.lng, d.lat]);
        return (
          <circle
            className="cities"
            key={d.city}
            cx={x}
            cy={y}
            r={sizeScale(sizeValue(d))}
          >
            <title>{d.city} - {format(',d')(d.population)}</title>
          </circle>
        );
      })}
    </g>
  );
};
